from .core import KMSServer, Activator, config, get_logger
from .core.utils import download_vlmcsd

import argparse,sys

# 获取logger
logger = get_logger(__name__)

def main():
    parser = argparse.ArgumentParser(description="HEU_KMS_Activator-like KMS activation tool")
    subparsers = parser.add_subparsers(dest='command', required=True)
    
    # Server commands
    server_parser = subparsers.add_parser('server', help='KMS server management')
    server_subparsers = server_parser.add_subparsers(dest='server_command', required=True)
    
    server_start = server_subparsers.add_parser('start', help='Start KMS server')
    server_start.add_argument('-b', '--background', action='store_true', help='Run in background')
    
    server_stop = server_subparsers.add_parser('stop', help='Stop KMS server')
    
    server_status = server_subparsers.add_parser('status', help='Check server status')
    
    server_test = server_subparsers.add_parser('test', help='Test server functionality')
    
    # Activation commands
    activate_parser = subparsers.add_parser('activate', help='Activation commands')
    activate_subparsers = activate_parser.add_subparsers(dest='activate_command', required=True)
    
    activate_windows = activate_subparsers.add_parser('windows', help='Activate Windows')
    
    activate_office = activate_subparsers.add_parser('office', help='Activate Office')
    activate_office.add_argument('-v', '--version', help='Specific Office version to activate')
    
    activate_all = activate_subparsers.add_parser('all', help='Activate Windows and Office')
    
    # Check status
    status_parser = subparsers.add_parser('status', help='Check activation status')
    
    # Configuration
    config_parser = subparsers.add_parser('config', help='Configuration management')
    config_subparsers = config_parser.add_subparsers(dest='config_command', required=True)
    
    config_set = config_subparsers.add_parser('set', help='Set configuration value')
    config_set.add_argument('key', help='Configuration key')
    config_set.add_argument('value', help='Configuration value')
    
    config_get = config_subparsers.add_parser('get', help='Get configuration value')
    config_get.add_argument('key', help='Configuration key')
    
    config_list = config_subparsers.add_parser('list', help='List all configurations')
    
    # Install vlmcsd
    install_parser = subparsers.add_parser('install', help='Install vlmcsd binary')
    
    args = parser.parse_args()
    
    # Execute commands
    if args.command == 'server':
        server = KMSServer()
        
        if args.server_command == 'start':
            if server.start(background=args.background):
                logger.info("KMS server started successfully")
            else:
                logger.error("Failed to start KMS server")
                sys.exit(1)
        
        elif args.server_command == 'stop':
            if server.stop():
                logger.info("KMS server stopped")
            else:
                logger.error("Failed to stop KMS server")
                sys.exit(1)
        
        elif args.server_command == 'status':
            status = server.status()
            logger.info(f"KMS server status: {status}")
        
        elif args.server_command == 'test':
            if server.test():
                logger.info("KMS server test successful")
            else:
                logger.error("KMS server test failed")
                sys.exit(1)
    
    elif args.command == 'activate':
        activator = Activator()
        
        if args.activate_command == 'windows':
            if activator.activate_windows():
                logger.info("Windows activated successfully")
            else:
                logger.error("Windows activation failed")
                sys.exit(1)
        
        elif args.activate_command == 'office':
            if activator.activate_office(version=args.version):
                logger.info("Office activated successfully")
            else:
                logger.error("Office activation failed")
                sys.exit(1)
        
        elif args.activate_command == 'all':
            win_success = activator.activate_windows()
            office_success = activator.activate_office()
            
            if win_success and office_success:
                logger.info("Windows and Office activated successfully")
            else:
                logger.error("Activation failed for some products")
                sys.exit(1)
    
    elif args.command == 'status':
        activator = Activator()
        status = activator.check_activation_status()
        
        print("\n=== Activation Status ===")
        print(f"Windows: {status['windows']}")
        
        if status['office']:
            print("\nOffice:")
            for version, state in status['office'].items():
                print(f"  {version}: {state}")
        else:
            print("\nNo Office installations found")
    
    elif args.command == 'config':
        if args.config_command == 'set':
            config.set(args.key, args.value)
            logger.info(f"Configuration updated: {args.key} = {args.value}")
        
        elif args.config_command == 'get':
            value = config.get(args.key)
            print(f"{args.key} = {value}")
        
        elif args.config_command == 'list':
            for key, value in config.config.items():
                print(f"{key} = {value}")
    
    elif args.command == 'install':
        if download_vlmcsd():
            logger.info("vlmcsd installed successfully")
        else:
            logger.error("Failed to install vlmcsd")
            sys.exit(1)

if __name__ == "__main__":
    main()


from setuptools import find_packages, setup
import os
from glob import glob

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# 获取所有二进制文件路径
def get_bin_files():
    bin_files = []
    # 遍历kms_activator/bin目录下的所有文件
    for root, _, files in os.walk("htyy/kms_activator/bin"):
        for file in files:
            bin_files.append(os.path.relpath(os.path.join(root, file), "htyy"))
    return bin_files

# 获取所有其他资源文件（如配置文件）
def get_resource_files():
    resource_files = []
    # 添加配置文件
    resource_files.append("kms_activator/config.json")
    
    # 添加其他资源文件（如果有）
    # resource_files.extend(glob("kms_activator/resources/*"))
    
    return resource_files

setup(
    name='htyy',
    version='0.1.2',  # 更新版本号
    description='htyy - All-in-one productivity tools',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='huang yi yi',
    author_email='363766687@qq.com',
    packages=find_packages(),
    package_dir={'htyy': 'htyy'},
    package_data={
        "htyy": [
            "*.pyd", 
            "*.pyi",
            # 包含KMS模块的所有二进制文件和资源
            "kms_activator/bin/**/*", 
            "kms_activator/bin/**/**/*",
            "kms_activator/config.json"
        ],
    },
    include_package_data=True,
    python_requires='>=3.6',
    install_requires=[
        "watchdog",
        "paramiko",
        "pycryptodome",
        "pywin32",
        "rich",
        "plyer",
        "mpmath",
        "miniaudio",
        "argostranslate",
        "googletrans",
        "pyautogui",
        "py7zr",
        "cryptography",
        # 添加KMS模块的依赖
        "requests>=2.25.1",
        "tqdm>=4.60.0",
        "colorama>=0.4.4",
    ],
    entry_points={
        'console_scripts': [
            # KMS激活器命令行工具
            'htyy-kms = htyy.kms_activator.cli:main',
            'kms-activator = htyy.kms_activator.cli:main',
        ],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Operating System :: MacOS",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Utilities",
    ],
    project_urls={
        "Source": "https://github.com/hyy-PROG/htyy",
    },
)


import os
import subprocess
import time
import threading
from .utils import run_command, get_vlmcsd_path, logger
from .config import config

class KMSServer:
    def __init__(self):
        self.process = None
        self.port = config.get('kms_port')
        self.server_ip = config.get('kms_server')
        self.vlmcsd_path = get_vlmcsd_path()
        self.is_running = False
    
    def start(self, background=True):
        """启动KMS服务器"""
        if not self.vlmcsd_path:
            logger.error("vlmcsd not found. Please install it first.")
            return False
        
        if self.is_running:
            logger.info("KMS server is already running")
            return True
        
        try:
            cmd = [self.vlmcsd_path, "-e", "-v", "-p", str(self.port)]
            
            if background:
                # 在后台运行
                if os.name == 'nt':  # Windows
                    self.process = subprocess.Popen(
                        cmd, 
                        stdout=subprocess.DEVNULL, 
                        stderr=subprocess.DEVNULL,
                        creationflags=subprocess.CREATE_NO_WINDOW
                    )
                else:  # Linux/Mac
                    self.process = subprocess.Popen(
                        cmd, 
                        stdout=subprocess.DEVNULL, 
                        stderr=subprocess.DEVNULL,
                        start_new_session=True
                    )
                
                # 检查进程是否启动成功
                time.sleep(1)
                if self.process.poll() is None:
                    self.is_running = True
                    logger.info(f"KMS server started on port {self.port}")
                    return True
                else:
                    logger.error("Failed to start KMS server")
                    return False
            else:
                # 在前台运行
                logger.info(f"Starting KMS server on port {self.port}...")
                self.process = subprocess.Popen(cmd)
                self.is_running = True
                self.process.wait()
                self.is_running = False
                return True
        except Exception as e:
            logger.error(f"Error starting KMS server: {e}")
            return False
    
    def stop(self):
        """停止KMS服务器"""
        if not self.is_running:
            logger.info("KMS server is not running")
            return True
        
        try:
            if os.name == 'nt':  # Windows
                run_command(['taskkill', '/F', '/PID', str(self.process.pid)])
            else:  # Linux/Mac
                run_command(['kill', '-9', str(self.process.pid)])
            
            self.is_running = False
            logger.info("KMS server stopped")
            return True
        except Exception as e:
            logger.error(f"Error stopping KMS server: {e}")
            return False
    
    def status(self):
        """检查KMS服务器状态"""
        if not self.is_running:
            return "Stopped"
        
        try:
            # 检查进程是否仍在运行
            if self.process.poll() is None:
                return "Running"
            else:
                self.is_running = False
                return "Stopped"
        except:
            return "Unknown"
    
    def test(self):
        """测试KMS服务器是否正常工作"""
        if not self.vlmcsd_path:
            logger.error("vlmcsd not found")
            return False
        
        cmd = [self.vlmcsd_path, "-v", "-T", self.server_ip, str(self.port)]
        retcode, stdout, stderr = run_command(cmd)
        
        if retcode == 0 and "successful" in stdout:
            logger.info("KMS server test successful")
            return True
        else:
            logger.error(f"KMS server test failed: {stderr or stdout}")
            return False